'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

function _interopDefault (ex) { return (ex && (typeof ex === 'object') && 'default' in ex) ? ex['default'] : ex; }

var _extends = _interopDefault(require('@babel/runtime/helpers/extends'));
var _defineProperty = _interopDefault(require('@babel/runtime/helpers/defineProperty'));
var _objectWithoutProperties = _interopDefault(require('@babel/runtime/helpers/objectWithoutProperties'));
var core = require('@westpac/core');
var react = require('react');
var PropTypes = _interopDefault(require('prop-types'));

var Wrapper = function Wrapper(_ref) {
  var state = _ref.state,
      rest = _objectWithoutProperties(_ref, ["state"]);

  return core.jsx("div", rest);
};

var wrapperStyles = function wrapperStyles() {
  var _useBrand = core.useBrand(),
      COLORS = _useBrand.COLORS;

  return {
    '@media screen and (max-width: 480px)': {
      width: '100%',
      marginBottom: '1.125rem',
      overflowY: 'hidden',
      overflowX: 'auto',
      border: "1px solid ".concat(COLORS.border)
    }
  };
};

var wrapperAttributes = function wrapperAttributes() {
  return null;
};

var defaultWrapper = {
  component: Wrapper,
  styles: wrapperStyles,
  attributes: wrapperAttributes
};

var Table = function Table(_ref) {
  var state = _ref.state,
      rest = _objectWithoutProperties(_ref, ["state"]);

  return core.jsx("table", rest);
};

var tableStyles = function tableStyles(_, _ref2) {
  var striped = _ref2.striped;

  var _useBrand = core.useBrand(),
      COLORS = _useBrand.COLORS;

  return {
    width: '100%',
    maxWidth: '100%',
    marginBottom: '1.3125rem',
    backgroundColor: '#fff',
    borderCollapse: 'collapse',
    // Odd row
    'tbody > tr:nth-of-type(even)': {
      backgroundColor: striped && COLORS.light
    },
    // Adjacent `tbody` elements
    'tbody + tbody': {
      borderTop: "2px solid ".concat(COLORS.hero)
    }
  };
};

var tableAttributes = function tableAttributes() {
  return null;
};

var defaultTable = {
  component: Table,
  styles: tableStyles,
  attributes: tableAttributes
};

var pkg = {
	name: "@westpac/table",
	version: "1.0.0-beta.2",
	description: "Table component for the Westpac GEL",
	repository: "https://github.com/WestpacGEL/GEL/tree/master/components/table",
	author: "Westpac GEL Team <gel@westpac.com.au>",
	contributors: [
		{
			name: "Dominik Wilkowski",
			email: "Hi@Dominik-Wilkowski.com",
			url: "https://dominik-wilkowski.com"
		},
		{
			name: "Jonathan Stening",
			email: "info@jonathanstening.com",
			url: "http://jonathanstening.com"
		}
	],
	license: "GPL-3.0+",
	scripts: {
		start: "PACKAGE_NAME=table webpack-dev-server --config ../../helpers/example/start.webpack.config.js",
		test: "exit 0 # start-server-and-test start http://localhost:8080 test:all",
		"test:dev": "start-server-and-test start http://localhost:8080 test:test-dev",
		"test:all": "yarn test:integration",
		"test:integration": "cypress run",
		"test:test-dev": "cypress open"
	},
	main: "dist/table.cjs.js",
	module: "dist/table.esm.js",
	dependencies: {
		"@babel/runtime": "^7.9.6",
		"@westpac/core": "^1.0.1",
		"prop-types": "^15.7.2"
	},
	peerDependencies: {
		react: "^16.13.1"
	},
	devDependencies: {
		cypress: "^4.5.0",
		react: "^16.13.1",
		"start-server-and-test": "^1.11.0"
	}
};

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }
// Context and Consumer Hook
// ==============================

var TableContext = react.createContext();
var useTableContext = function useTableContext() {
  var context = react.useContext(TableContext);

  if (!context) {
    throw new Error('Table sub-components should be wrapped in a <Table>.');
  }

  return context;
}; // ==============================
// Component
// ==============================

var Table$1 = function Table(_ref) {
  var striped = _ref.striped,
      bordered = _ref.bordered,
      children = _ref.children,
      componentOverrides = _ref.overrides,
      rest = _objectWithoutProperties(_ref, ["striped", "bordered", "children", "overrides"]);

  var context = react.useContext(TableContext);
  bordered = context && context.bordered || bordered;

  var _useBrand = core.useBrand(),
      tokenOverrides = _useBrand.OVERRIDES[pkg.name],
      brandOverrides = _useBrand[pkg.name];

  var defaultOverrides = {
    Wrapper: defaultWrapper,
    Table: defaultTable
  };

  var state = _objectSpread({
    striped: striped,
    bordered: bordered,
    overrides: componentOverrides
  }, rest);

  var _overrideReconciler = core.overrideReconciler(defaultOverrides, tokenOverrides, brandOverrides, componentOverrides),
      _overrideReconciler$W = _overrideReconciler.Wrapper,
      Wrapper = _overrideReconciler$W.component,
      wrapperStyles = _overrideReconciler$W.styles,
      wrapperAttributes = _overrideReconciler$W.attributes,
      _overrideReconciler$T = _overrideReconciler.Table,
      Table = _overrideReconciler$T.component,
      tableStyles = _overrideReconciler$T.styles,
      tableAttributes = _overrideReconciler$T.attributes;

  return core.jsx(TableContext.Provider, {
    value: {
      striped: striped,
      bordered: bordered,
      state: state
    }
  }, core.jsx(Wrapper, _extends({
    state: state
  }, wrapperAttributes(state), {
    css: wrapperStyles(state)
  }), core.jsx(Table, _extends({}, rest, {
    state: state
  }, tableAttributes(state), {
    css: tableStyles(state)
  }), children)));
}; // ==============================
// Types
// ==============================

Table$1.propTypes = {
  /**
   * Striped mode
   */
  striped: PropTypes.bool,

  /**
   * Bordered mode
   */
  bordered: PropTypes.bool,

  /**
   * The override API
   */
  overrides: PropTypes.shape({
    Table: PropTypes.shape({
      styles: PropTypes.func,
      component: PropTypes.elementType,
      attributes: PropTypes.func
    }),
    Caption: PropTypes.shape({
      styles: PropTypes.func,
      component: PropTypes.elementType,
      attributes: PropTypes.func
    }),
    Tbody: PropTypes.shape({
      styles: PropTypes.func,
      component: PropTypes.elementType,
      attributes: PropTypes.func
    }),
    Td: PropTypes.shape({
      styles: PropTypes.func,
      component: PropTypes.elementType,
      attributes: PropTypes.func
    }),
    Tfoot: PropTypes.shape({
      styles: PropTypes.func,
      component: PropTypes.elementType,
      attributes: PropTypes.func
    }),
    Th: PropTypes.shape({
      styles: PropTypes.func,
      component: PropTypes.elementType,
      attributes: PropTypes.func
    }),
    Thead: PropTypes.shape({
      styles: PropTypes.func,
      component: PropTypes.elementType,
      attributes: PropTypes.func
    }),
    Tr: PropTypes.shape({
      styles: PropTypes.func,
      component: PropTypes.elementType,
      attributes: PropTypes.func
    })
  })
};
Table$1.defaultProps = {
  bordered: false,
  striped: false
};

function ownKeys$1(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread$1(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys$1(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys$1(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

var Caption = function Caption(_ref) {
  var state = _ref.state,
      rest = _objectWithoutProperties(_ref, ["state"]);

  return core.jsx("caption", rest);
};

var captionStyles = function captionStyles() {
  var _useBrand = core.useBrand(),
      TYPE = _useBrand.TYPE;

  return _objectSpread$1({
    fontSize: '1.125rem',
    textAlign: 'left',
    marginBottom: '0.75rem'
  }, TYPE.bodyFont[300]);
};

var captionAttributes = function captionAttributes() {
  return null;
};

var defaultCaption = {
  component: Caption,
  styles: captionStyles,
  attributes: captionAttributes
};

function ownKeys$2(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread$2(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys$2(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys$2(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }
// Component
// ==============================

var Caption$1 = function Caption(_ref) {
  var children = _ref.children,
      overrides = _ref.overrides,
      rest = _objectWithoutProperties(_ref, ["children", "overrides"]);

  var _useBrand = core.useBrand(),
      tokenOverrides = _useBrand.OVERRIDES[pkg.name],
      brandOverrides = _useBrand[pkg.name];

  var context = useTableContext();
  var defaultOverrides = {
    Caption: defaultCaption
  };
  var componentOverrides = overrides || context.state.overrides;

  var state = _objectSpread$2({
    context: context.state,
    overrides: componentOverrides
  }, rest);

  var _overrideReconciler = core.overrideReconciler(defaultOverrides, tokenOverrides, brandOverrides, componentOverrides),
      _overrideReconciler$C = _overrideReconciler.Caption,
      Caption = _overrideReconciler$C.component,
      CaptionStyles = _overrideReconciler$C.styles,
      CaptionAttributes = _overrideReconciler$C.attributes;

  return core.jsx(Caption, _extends({}, rest, {
    state: state
  }, CaptionAttributes(state), {
    css: CaptionStyles(state)
  }), children);
}; // ==============================
// Types
// ==============================

Caption$1.propTypes = {
  /**
   * The override API
   */
  overrides: PropTypes.shape({
    Caption: PropTypes.shape({
      styles: PropTypes.func,
      component: PropTypes.elementType,
      attributes: PropTypes.func
    })
  })
};

function ownKeys$3(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread$3(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys$3(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys$3(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

var Thead = function Thead(_ref) {
  var state = _ref.state,
      rest = _objectWithoutProperties(_ref, ["state"]);

  return core.jsx("thead", rest);
};

var theadStyles = function theadStyles(_, _ref2) {
  var bordered = _ref2.bordered;

  var _useBrand = core.useBrand(),
      COLORS = _useBrand.COLORS,
      TYPE = _useBrand.TYPE;

  return {
    'th, td': {
      borderTop: !bordered && 0
    },
    // `th` cells in the `thead`
    th: _objectSpread$3({
      verticalAlign: 'bottom',
      borderBottom: "".concat(bordered ? '2px' : '3px', " solid ").concat(COLORS.hero),
      color: COLORS.text
    }, TYPE.bodyFont[700])
  };
};

var theadAttributes = function theadAttributes() {
  return null;
};

var defaultThead = {
  component: Thead,
  styles: theadStyles,
  attributes: theadAttributes
};

function ownKeys$4(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread$4(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys$4(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys$4(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }
// Component
// ==============================

var Thead$1 = function Thead(_ref) {
  var bordered = _ref.bordered,
      children = _ref.children,
      overrides = _ref.overrides,
      rest = _objectWithoutProperties(_ref, ["bordered", "children", "overrides"]);

  var _useBrand = core.useBrand(),
      tokenOverrides = _useBrand.OVERRIDES[pkg.name],
      brandOverrides = _useBrand[pkg.name];

  var context = useTableContext();
  bordered = context && context.bordered || bordered;
  var defaultOverrides = {
    Thead: defaultThead
  };
  var componentOverrides = overrides || context.state.overrides;

  var state = _objectSpread$4({
    bordered: bordered,
    context: context.state,
    overrides: componentOverrides
  }, rest);

  var _overrideReconciler = core.overrideReconciler(defaultOverrides, tokenOverrides, brandOverrides, componentOverrides),
      _overrideReconciler$T = _overrideReconciler.Thead,
      Thead = _overrideReconciler$T.component,
      theadStyles = _overrideReconciler$T.styles,
      theadAttributes = _overrideReconciler$T.attributes;

  return core.jsx(Thead, _extends({}, rest, {
    state: state
  }, theadAttributes(state), {
    css: theadStyles(state)
  }), children);
}; // ==============================
// Types
// ==============================

Thead$1.propTypes = {
  /**
   * Whether or not there should border styling
   */
  bordered: PropTypes.bool,

  /**
   * The override API
   */
  overrides: PropTypes.shape({
    Thead: PropTypes.shape({
      styles: PropTypes.func,
      component: PropTypes.elementType,
      attributes: PropTypes.func
    })
  })
};

var Tr = function Tr(_ref) {
  var state = _ref.state,
      rest = _objectWithoutProperties(_ref, ["state"]);

  return core.jsx("tr", rest);
};
var trStyles = function trStyles(_, _ref2) {
  var striped = _ref2.striped,
      highlighted = _ref2.highlighted;

  var _useBrand = core.useBrand(),
      COLORS = _useBrand.COLORS;

  return {
    transition: !striped && 'background 0.2s ease',
    borderLeft: typeof highlighted === 'boolean' && highlighted ? "6px solid ".concat(COLORS.primary) : 0,
    borderBottom: typeof highlighted === 'boolean' && highlighted ? "3px solid ".concat(COLORS.primary) : "1px solid ".concat(COLORS.border),
    //a11y: highlighted border must be noticeably thicker than non-highlighted
    // Hovered row
    'tbody > &:hover': {
      backgroundColor: !striped && COLORS.background
    }
  };
};

var trAttributes = function trAttributes() {
  return null;
};

var defaultTr = {
  component: Tr,
  styles: trStyles,
  attributes: trAttributes
};

function ownKeys$5(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread$5(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys$5(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys$5(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }
// Utils
// ==============================

var generateHighlightMap = function generateHighlightMap(highlighted, tdCount) {
  var map = Array(tdCount).fill(false);
  highlighted.forEach(function (highlight) {
    if (typeof highlight === 'number') {
      map[highlight] = true;
    } else if (Array.isArray(highlight)) {
      map.fill(true, highlight[0], highlight[1] + 1);
    }
  });
  return map;
}; // ==============================
// Component
// ==============================


var Tr$1 = function Tr(_ref) {
  var striped = _ref.striped,
      highlighted = _ref.highlighted,
      children = _ref.children,
      overrides = _ref.overrides,
      rest = _objectWithoutProperties(_ref, ["striped", "highlighted", "children", "overrides"]);

  var _useBrand = core.useBrand(),
      tokenOverrides = _useBrand.OVERRIDES[pkg.name],
      brandOverrides = _useBrand[pkg.name];

  var context = useTableContext();
  striped = context && context.striped || striped;
  var defaultOverrides = {
    Tr: defaultTr
  };
  var componentOverrides = overrides || context.state.overrides;

  var state = _objectSpread$5({
    striped: striped,
    highlighted: highlighted,
    context: context.state,
    overrides: componentOverrides
  }, rest);

  var _overrideReconciler = core.overrideReconciler(defaultOverrides, tokenOverrides, brandOverrides, componentOverrides),
      _overrideReconciler$T = _overrideReconciler.Tr,
      Tr = _overrideReconciler$T.component,
      trStyles = _overrideReconciler$T.styles,
      trAttributes = _overrideReconciler$T.attributes;

  var highlightedChildren;

  if (Array.isArray(highlighted)) {
    var highlightMap = generateHighlightMap(highlighted, react.Children.count(children));
    highlightedChildren = react.Children.map(children, function (child, index) {
      if (highlightMap[index] === true) {
        if (index === 0 || highlightMap[index - 1] === false) {
          return react.cloneElement(child, {
            highlightStart: true,
            highlighted: true
          });
        } else {
          return react.cloneElement(child, {
            highlighted: true
          });
        }
      } else {
        return child;
      }
    });
  }

  return core.jsx(Tr, _extends({}, rest, {
    state: state
  }, trAttributes(state), {
    css: trStyles(state)
  }), highlightedChildren || children);
}; // ==============================
// Types
// ==============================

Tr$1.propTypes = {
  /**
   * Highlighted mode
   */
  highlighted: PropTypes.oneOfType([PropTypes.bool, PropTypes.array]),

  /**
   * The override API
   */
  overrides: PropTypes.shape({
    Tr: PropTypes.shape({
      styles: PropTypes.func,
      component: PropTypes.elementType,
      attributes: PropTypes.func
    })
  })
};
Tr$1.defaultProps = {
  highlighted: false
};

var Th = function Th(_ref) {
  var state = _ref.state,
      rest = _objectWithoutProperties(_ref, ["state"]);

  return core.jsx("th", rest);
};

var thStyles = function thStyles(_, _ref2) {
  var bordered = _ref2.bordered;

  var _useBrand = core.useBrand(),
      COLORS = _useBrand.COLORS;

  return {
    padding: '0.75rem',
    verticalAlign: 'top',
    border: "1px solid ".concat(COLORS.border),
    borderLeft: !bordered && 0,
    borderRight: !bordered && 0,
    textAlign: 'left'
  };
};

var thAttributes = function thAttributes() {
  return null;
};

var defaultTh = {
  component: Th,
  styles: thStyles,
  attributes: thAttributes
};

function ownKeys$6(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread$6(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys$6(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys$6(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }
// Component
// ==============================

var Th$1 = function Th(_ref) {
  var bordered = _ref.bordered,
      children = _ref.children,
      overrides = _ref.overrides,
      rest = _objectWithoutProperties(_ref, ["bordered", "children", "overrides"]);

  var _useBrand = core.useBrand(),
      tokenOverrides = _useBrand.OVERRIDES[pkg.name],
      brandOverrides = _useBrand[pkg.name];

  var context = useTableContext();
  bordered = context && context.bordered || bordered;
  var defaultOverrides = {
    Th: defaultTh
  };
  var componentOverrides = overrides || context.state.overrides;

  var state = _objectSpread$6({
    bordered: bordered,
    context: context.state,
    overrides: componentOverrides
  }, rest);

  var _overrideReconciler = core.overrideReconciler(defaultOverrides, tokenOverrides, brandOverrides, componentOverrides),
      _overrideReconciler$T = _overrideReconciler.Th,
      Th = _overrideReconciler$T.component,
      thStyles = _overrideReconciler$T.styles,
      thAttributes = _overrideReconciler$T.attributes;

  return core.jsx(Th, _extends({}, rest, {
    state: state
  }, thAttributes(state), {
    css: thStyles(state)
  }), children);
}; // ==============================
// Types
// ==============================

Th$1.propTypes = {
  /**
   * Whether or not there should border styling
   */
  bordered: PropTypes.bool,

  /**
   * The override API
   */
  overrides: PropTypes.shape({
    Th: PropTypes.shape({
      styles: PropTypes.func,
      component: PropTypes.elementType,
      attributes: PropTypes.func
    })
  })
};

var Tbody = function Tbody(_ref) {
  var state = _ref.state,
      rest = _objectWithoutProperties(_ref, ["state"]);

  return core.jsx("tbody", rest);
};

var tbodyStyles = function tbodyStyles() {
  return {};
};

var tbodyAttributes = function tbodyAttributes() {
  return null;
};

var defaultTBody = {
  component: Tbody,
  styles: tbodyStyles,
  attributes: tbodyAttributes
};

function ownKeys$7(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread$7(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys$7(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys$7(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }
// Component
// ==============================

var Tbody$1 = function Tbody(_ref) {
  var children = _ref.children,
      overrides = _ref.overrides,
      rest = _objectWithoutProperties(_ref, ["children", "overrides"]);

  var _useBrand = core.useBrand(),
      tokenOverrides = _useBrand.OVERRIDES[pkg.name],
      brandOverrides = _useBrand[pkg.name];

  var context = useTableContext();
  var defaultOverrides = {
    Tbody: defaultTBody
  };
  var componentOverrides = overrides || context.state.overrides;

  var state = _objectSpread$7({
    context: context.state,
    overrides: componentOverrides
  }, rest);

  var _overrideReconciler = core.overrideReconciler(defaultOverrides, tokenOverrides, brandOverrides, componentOverrides),
      _overrideReconciler$T = _overrideReconciler.Tbody,
      Tbody = _overrideReconciler$T.component,
      tbodyStyles = _overrideReconciler$T.styles,
      tbodyAttributes = _overrideReconciler$T.attributes;

  return core.jsx(Tbody, _extends({}, rest, {
    state: state
  }, tbodyAttributes(state), {
    css: tbodyStyles(state)
  }), children);
}; // ==============================
// Types
// ==============================

Tbody$1.propTypes = {
  /**
   * The override API
   */
  overrides: PropTypes.shape({
    Tbody: PropTypes.shape({
      styles: PropTypes.func,
      component: PropTypes.elementType,
      attributes: PropTypes.func
    })
  })
};

function ownKeys$8(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread$8(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys$8(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys$8(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

var Td = function Td(_ref) {
  var state = _ref.state,
      rest = _objectWithoutProperties(_ref, ["state"]);

  return core.jsx("td", rest);
};

var tdStyles = function tdStyles(_, _ref2) {
  var highlighted = _ref2.highlighted,
      highlightStart = _ref2.highlightStart,
      bordered = _ref2.bordered;

  var _useBrand = core.useBrand(),
      COLORS = _useBrand.COLORS,
      TYPE = _useBrand.TYPE;

  return {
    padding: '0.75rem',
    verticalAlign: 'top',
    border: bordered && "1px solid ".concat(COLORS.border),
    borderLeft: highlightStart && "6px solid ".concat(COLORS.primary),
    borderBottom: highlighted && "3px solid ".concat(COLORS.primary),
    //a11y: highlighted border must be noticeably thicker than non-highlighted
    // bold scope
    '&[scope=row]': _objectSpread$8({}, TYPE.bodyFont[700])
  };
};

var tdAttributes = function tdAttributes() {
  return null;
};

var defaultTd = {
  component: Td,
  styles: tdStyles,
  attributes: tdAttributes
};

function ownKeys$9(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread$9(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys$9(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys$9(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }
// Component
// ==============================

var Td$1 = function Td(_ref) {
  var highlighted = _ref.highlighted,
      highlightStart = _ref.highlightStart,
      bordered = _ref.bordered,
      children = _ref.children,
      overrides = _ref.overrides,
      rest = _objectWithoutProperties(_ref, ["highlighted", "highlightStart", "bordered", "children", "overrides"]);

  var _useBrand = core.useBrand(),
      tokenOverrides = _useBrand.OVERRIDES[pkg.name],
      brandOverrides = _useBrand[pkg.name];

  var context = useTableContext();
  bordered = context && context.bordered || bordered;
  var defaultOverrides = {
    Td: defaultTd
  };
  var componentOverrides = overrides || context.state.overrides;

  var state = _objectSpread$9({
    highlighted: highlighted,
    highlightStart: highlightStart,
    bordered: bordered,
    context: context.state,
    overrides: componentOverrides
  }, rest);

  var _overrideReconciler = core.overrideReconciler(defaultOverrides, tokenOverrides, brandOverrides, componentOverrides),
      _overrideReconciler$T = _overrideReconciler.Td,
      Td = _overrideReconciler$T.component,
      tdStyles = _overrideReconciler$T.styles,
      tdAttributes = _overrideReconciler$T.attributes;

  return core.jsx(Td, _extends({}, rest, {
    state: state
  }, tdAttributes(state), {
    css: tdStyles(state)
  }), children);
}; // ==============================
// Types
// ==============================

Td$1.propTypes = {
  /**
   * Whether or not the cell is highlighted
   */
  highlighted: PropTypes.bool,

  /**
   * Whether or not the start of the highlighted cells
   */
  highlightStart: PropTypes.bool,

  /**
   * Bordered mode
   */
  bordered: PropTypes.bool,

  /**
   * The override API
   */
  overrides: PropTypes.shape({
    Td: PropTypes.shape({
      styles: PropTypes.func,
      component: PropTypes.elementType,
      attributes: PropTypes.func
    })
  })
};
Td$1.defaultProps = {
  highlighted: false,
  highlightStart: false
};

var TFoot = function TFoot(_ref) {
  var state = _ref.state,
      rest = _objectWithoutProperties(_ref, ["state"]);

  return core.jsx("tfoot", rest);
};

var tfootStyles = function tfootStyles(_, _ref2) {
  var bordered = _ref2.bordered;

  var _useBrand = core.useBrand(),
      COLORS = _useBrand.COLORS;

  return {
    color: COLORS.muted,
    'th, tr, td': {
      borderBottom: !bordered && 0
    }
  };
};

var tfootAttributes = function tfootAttributes() {
  return null;
};

var defaultTfoot = {
  component: TFoot,
  styles: tfootStyles,
  attributes: tfootAttributes
};

function ownKeys$a(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread$a(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys$a(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys$a(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }
// Component
// ==============================

var Tfoot = function Tfoot(_ref) {
  var bordered = _ref.bordered,
      children = _ref.children,
      overrides = _ref.overrides,
      rest = _objectWithoutProperties(_ref, ["bordered", "children", "overrides"]);

  var _useBrand = core.useBrand(),
      tokenOverrides = _useBrand.OVERRIDES[pkg.name],
      brandOverrides = _useBrand[pkg.name];

  var context = useTableContext();
  bordered = context && context.bordered || bordered;
  var defaultOverrides = {
    Tfoot: defaultTfoot
  };
  var componentOverrides = overrides || context.state.overrides;

  var state = _objectSpread$a({
    bordered: bordered,
    context: context.state,
    overrides: componentOverrides
  }, rest);

  var _overrideReconciler = core.overrideReconciler(defaultOverrides, tokenOverrides, brandOverrides, componentOverrides),
      _overrideReconciler$T = _overrideReconciler.Tfoot,
      Tfoot = _overrideReconciler$T.component,
      tfootStyles = _overrideReconciler$T.styles,
      tfootAttributes = _overrideReconciler$T.attributes;

  return core.jsx(Tfoot, _extends({}, rest, {
    state: state
  }, tfootAttributes(state), {
    css: tfootStyles(state)
  }), children);
}; // ==============================
// Types
// ==============================

Tfoot.propTypes = {
  /**
   * Whether or not there should border styling
   */
  bordered: PropTypes.bool,

  /**
   * The override API
   */
  overrides: PropTypes.shape({
    Tfoot: PropTypes.shape({
      styles: PropTypes.func,
      component: PropTypes.elementType,
      attributes: PropTypes.func
    })
  })
};

exports.Caption = Caption$1;
exports.Table = Table$1;
exports.Tbody = Tbody$1;
exports.Td = Td$1;
exports.Tfoot = Tfoot;
exports.Th = Th$1;
exports.Thead = Thead$1;
exports.Tr = Tr$1;
